==> temp_mails-2.1.2-py3-none-any.whl: temp_mails/providers/txen_de.py <==
import json

from bs4 import BeautifulSoup
import requests

from .._constructors import _Livewire2

class Txen_de(_Livewire2):
    """An API Wrapper around the https://www.txen.de/ website. From experience very fast."""

    def __init__(self, name: str=None, domain: str=None, exclude: list[str]=None):
        """
            Generate an inbox\n
            Args:\n
            name - name for the email, if None a random one is chosen\n
            domain - the domain to use, domain is prioritized over exclude\n
            exclude - a list of domain to exclude from the random selection\n
        """
        
        super().__init__(
            urls={
                "base": "https://www.txen.de",
                "mailbox": "https://www.txen.de/mailbox/",
                "app": "https://www.txen.de/livewire/message/frontend.app",
                "actions": "https://www.txen.de/livewire/message/frontend.actions"
            },
            order=-1, name=name, domain=domain, exclude=exclude
            )


    @staticmethod
    def get_valid_domains() -> list[str] | None:
        """
            Returns a list of a valid domains, None if failure
        """
        r = requests.get("https://www.txen.de/", headers={"User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/123.0.0.0 Safari/537.36"})

        if r.ok:
            soup = BeautifulSoup(r.text, "lxml")
            data = json.loads(soup.find(lambda tag: tag.name == "div" and "in_app: true" in tag.get("x-data", "") and ( "wire:initial-data" in tag.attrs ))["wire:initial-data"])

            return data["serverMemo"]["data"]["domains"]

==> temp_mails-2.2.0-py3-none-any.whl: temp_mails/providers/txen_de.py <==
import json

from bs4 import BeautifulSoup
import requests

from .._constructors import _Livewire2, GLOBAL_UA

class Txen_de(_Livewire2):
    """An API Wrapper around the https://txen.de/ website. From experience very fast."""

    def __init__(self, name: str=None, domain: str=None, exclude: list[str]=None):
        """
            Generate an inbox\n
            Args:\n
            name - name for the email, if None a random one is chosen\n
            domain - the domain to use, domain is prioritized over exclude\n
            exclude - a list of domain to exclude from the random selection\n
        """
        
        super().__init__(
            urls={
                "base": "https://txen.de",
                "mailbox": "https://txen.de/mailbox/",
                "app": "https://txen.de/livewire/message/frontend.app",
                "actions": "https://txen.de/livewire/message/frontend.actions"
            },
            order=0, name=name, domain=domain, exclude=exclude
            )


    @staticmethod
    def get_valid_domains() -> list[str] | None:
        """
            Returns a list of a valid domains, None if failure
        """
        r = requests.get("https://txen.de/", headers={"User-Agent": GLOBAL_UA})

        if r.ok:
            soup = BeautifulSoup(r.text, "lxml")
            data = json.loads(soup.find(lambda tag: tag.name == "div" and "in_app: true" in tag.get("x-data", "") and ( "wire:initial-data" in tag.attrs ))["wire:initial-data"])

            return data["serverMemo"]["data"]["domains"]
